complete -c mullvad -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_use_subcommand" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_use_subcommand" -f -a "account" -d 'Control and display information about your Mullvad account'
complete -c mullvad -n "__fish_use_subcommand" -f -a "auto-connect" -d 'Control the daemon auto-connect setting'
complete -c mullvad -n "__fish_use_subcommand" -f -a "beta-program" -d 'Receive notifications about beta updates'
complete -c mullvad -n "__fish_use_subcommand" -f -a "lockdown-mode" -d 'Control whether to block network access when disconnected from VPN'
complete -c mullvad -n "__fish_use_subcommand" -f -a "debug" -d 'Debug commands used for internal testing of the app'
complete -c mullvad -n "__fish_use_subcommand" -f -a "dns" -d 'Configure DNS servers to use when connected'
complete -c mullvad -n "__fish_use_subcommand" -f -a "lan" -d 'Control the allow local network sharing setting'
complete -c mullvad -n "__fish_use_subcommand" -f -a "connect" -d 'Connect to a VPN relay'
complete -c mullvad -n "__fish_use_subcommand" -f -a "disconnect" -d 'Disconnect from the VPN'
complete -c mullvad -n "__fish_use_subcommand" -f -a "reconnect" -d 'Reconnect to any matching VPN relay'
complete -c mullvad -n "__fish_use_subcommand" -f -a "relay" -d 'Manage relay and tunnel constraints'
complete -c mullvad -n "__fish_use_subcommand" -f -a "api-access" -d 'Manage Mullvad API access methods'
complete -c mullvad -n "__fish_use_subcommand" -f -a "anti-censorship" -d 'Manage use of anti censorship methods for WireGuard. Can make WireGuard traffic look like something else on the network. Helps circumvent censorship and to establish a tunnel when on restricted networks'
complete -c mullvad -n "__fish_use_subcommand" -f -a "split-tunnel" -d 'Manage split tunneling. To launch applications outside the tunnel, use the program \'mullvad-exclude\' instead of this command'
complete -c mullvad -n "__fish_use_subcommand" -f -a "status" -d 'Return the state of the VPN tunnel'
complete -c mullvad -n "__fish_use_subcommand" -f -a "tunnel" -d 'Manage tunnel options'
complete -c mullvad -n "__fish_use_subcommand" -f -a "version" -d 'Show information about the current Mullvad version and available versions'
complete -c mullvad -n "__fish_use_subcommand" -f -a "shell-completions" -d 'Generate completion scripts for the specified shell'
complete -c mullvad -n "__fish_use_subcommand" -f -a "factory-reset" -d 'Reset settings, caches, and logs'
complete -c mullvad -n "__fish_use_subcommand" -f -a "reset-settings" -d 'Reset settings only, but remain logged in and keep logs and caches'
complete -c mullvad -n "__fish_use_subcommand" -f -a "custom-list" -d 'Manage custom lists'
complete -c mullvad -n "__fish_use_subcommand" -f -a "import-settings" -d 'Apply a JSON patch generated by \'export-settings\''
complete -c mullvad -n "__fish_use_subcommand" -f -a "export-settings" -d 'Export a JSON patch based on the current settings'
complete -c mullvad -n "__fish_use_subcommand" -f -a "log" -d 'Manage logs and tracing'
complete -c mullvad -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "create" -d 'Create and log in on a new account'
complete -c mullvad -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "login" -d 'Log in on an account'
complete -c mullvad -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "logout" -d 'Log out of the current account'
complete -c mullvad -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display information about the current account'
complete -c mullvad -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "list-devices" -d 'List devices associated with an account'
complete -c mullvad -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "revoke-device" -d 'Revoke a device associated with an account'
complete -c mullvad -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "redeem" -d 'Redeem a voucher'
complete -c mullvad -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from create" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from create" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from login" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from login" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from logout" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from logout" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from get" -s v -l verbose -d 'Enable verbose output'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from list-devices" -s a -l account -d 'Mullvad account number (current account if not specified)' -r
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from list-devices" -s v -l verbose -d 'Enable verbose output'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from list-devices" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from list-devices" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from revoke-device" -s a -l account -d 'Mullvad account number (current account if not specified)' -r
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from revoke-device" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from revoke-device" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from redeem" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from redeem" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "create" -d 'Create and log in on a new account'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "login" -d 'Log in on an account'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "logout" -d 'Log out of the current account'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display information about the current account'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "list-devices" -d 'List devices associated with an account'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "revoke-device" -d 'Revoke a device associated with an account'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "redeem" -d 'Redeem a voucher'
complete -c mullvad -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display the current auto-connect setting'
complete -c mullvad -n "__fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Change auto-connect setting'
complete -c mullvad -n "__fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from auto-connect; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from auto-connect; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from auto-connect; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from auto-connect; and __fish_seen_subcommand_from set" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from auto-connect; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display the current auto-connect setting'
complete -c mullvad -n "__fish_seen_subcommand_from auto-connect; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Change auto-connect setting'
complete -c mullvad -n "__fish_seen_subcommand_from auto-connect; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Get beta notifications setting'
complete -c mullvad -n "__fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Change beta notifications setting'
complete -c mullvad -n "__fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from beta-program; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from beta-program; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from beta-program; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from beta-program; and __fish_seen_subcommand_from set" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from beta-program; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Get beta notifications setting'
complete -c mullvad -n "__fish_seen_subcommand_from beta-program; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Change beta notifications setting'
complete -c mullvad -n "__fish_seen_subcommand_from beta-program; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display the current lockdown mode setting'
complete -c mullvad -n "__fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Change the lockdown mode setting'
complete -c mullvad -n "__fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from lockdown-mode; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from lockdown-mode; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from lockdown-mode; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from lockdown-mode; and __fish_seen_subcommand_from set" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from lockdown-mode; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display the current lockdown mode setting'
complete -c mullvad -n "__fish_seen_subcommand_from lockdown-mode; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Change the lockdown mode setting'
complete -c mullvad -n "__fish_seen_subcommand_from lockdown-mode; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from help" -f -a "block-connection" -d 'Block all internet connection by setting an invalid relay constraint'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from help" -f -a "relay" -d 'Relay'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from help" -f -a "rollout" -d 'Handy commands for interacting with the app release rollout system'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from block-connection" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from block-connection" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from help" -f -a "disable" -d 'Inactivate this _category of relays_ - a category can be one of the following: a relay, a city, a country'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from help" -f -a "enable" -d '(Re)Activate this _category of relays_ - a category can be one of the following: a relay, a city, a country'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from disable" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from disable" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from enable" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from enable" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from help" -f -a "disable" -d 'Inactivate this _category of relays_ - a category can be one of the following: a relay, a city, a country'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from help" -f -a "enable" -d '(Re)Activate this _category of relays_ - a category can be one of the following: a relay, a city, a country'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Print your rollout threshold'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed; and not __fish_seen_subcommand_from help" -f -a "reroll" -d 'Generate a new rollout threshold (overwrites the current threshold value)'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed; and not __fish_seen_subcommand_from help" -f -a "seed" -d 'Set your rollout threshold seed to a known value'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and __fish_seen_subcommand_from reroll" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and __fish_seen_subcommand_from reroll" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and __fish_seen_subcommand_from seed" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and __fish_seen_subcommand_from seed" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Print your rollout threshold'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed; and not __fish_seen_subcommand_from help" -f -a "reroll" -d 'Generate a new rollout threshold (overwrites the current threshold value)'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed; and not __fish_seen_subcommand_from help" -f -a "seed" -d 'Set your rollout threshold seed to a known value'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from help" -f -a "block-connection" -d 'Block all internet connection by setting an invalid relay constraint'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from help" -f -a "relay" -d 'Relay'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from help" -f -a "rollout" -d 'Handy commands for interacting with the app release rollout system'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from enable" -f -a "disable" -d 'Inactivate this _category of relays_ - a category can be one of the following: a relay, a city, a country'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from enable" -f -a "enable" -d '(Re)Activate this _category of relays_ - a category can be one of the following: a relay, a city, a country'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed" -f -a "get" -d 'Print your rollout threshold'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed" -f -a "reroll" -d 'Generate a new rollout threshold (overwrites the current threshold value)'
complete -c mullvad -n "__fish_seen_subcommand_from debug; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed" -f -a "seed" -d 'Set your rollout threshold seed to a known value'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display the current DNS settings'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Set DNS servers to use'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from default; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from default; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from default; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "default" -d 'Use a default DNS server, with or without content blocking'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from default; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "custom" -d 'Set a list of custom DNS servers'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from default; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from default" -l block-ads -d 'Block domains known to be used for ads'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from default" -l block-trackers -d 'Block domains known to be used for tracking'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from default" -l block-malware -d 'Block domains known to be used by malware'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from default" -l block-adult-content -d 'Block domains known to be used for adult content'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from default" -l block-gambling -d 'Block domains known to be used for gambling'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from default" -l block-social-media -d 'Block domains related to social media'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from default" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from default" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from custom" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from custom" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from default; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "default" -d 'Use a default DNS server, with or without content blocking'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from default; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "custom" -d 'Set a list of custom DNS servers'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from default; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display the current DNS settings'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Set DNS servers to use'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from default; and not __fish_seen_subcommand_from custom" -f -a "default" -d 'Use a default DNS server, with or without content blocking'
complete -c mullvad -n "__fish_seen_subcommand_from dns; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from default; and not __fish_seen_subcommand_from custom" -f -a "custom" -d 'Set a list of custom DNS servers'
complete -c mullvad -n "__fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display the current local network sharing setting'
complete -c mullvad -n "__fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Change allow LAN setting'
complete -c mullvad -n "__fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from lan; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from lan; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from lan; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from lan; and __fish_seen_subcommand_from set" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from lan; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display the current local network sharing setting'
complete -c mullvad -n "__fish_seen_subcommand_from lan; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Change allow LAN setting'
complete -c mullvad -n "__fish_seen_subcommand_from lan; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from connect" -s w -l wait -d 'Wait until connected before exiting'
complete -c mullvad -n "__fish_seen_subcommand_from connect" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from connect" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from disconnect" -s w -l wait -d 'Wait until disconnected before exiting'
complete -c mullvad -n "__fish_seen_subcommand_from disconnect" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from disconnect" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from reconnect" -s w -l wait -d 'Wait until connected before exiting'
complete -c mullvad -n "__fish_seen_subcommand_from reconnect" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from reconnect" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display the current relay constraints'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Set relay constraints, such as location and port'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -f -a "list" -d 'List available relays'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -f -a "update" -d 'Update the relay list'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -f -a "override" -d 'Override options for individual relays/servers'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "location" -d 'Select a relay using country, city or hostname. The \'mullvad relay list\' command shows the available relays and their geographical location'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "custom-list" -d 'Set custom list to select relays from. Use the \'custom-lists list\' command to show available alternatives'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "provider" -d 'Set hosting provider(s) to select relays from. The \'list\' command shows the available relays and their providers'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "ownership" -d 'Filter relays based on ownership. The \'list\' command shows the available relays and whether they\'re rented'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "ip-version" -d 'Set tunnel IP version constraint'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "multihop" -d 'Enable or disable multihop'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "entry" -d 'Set entry location constraints for multihop'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "custom" -d 'Set a custom WireGuard relay'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from location" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from location" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from custom-list" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from custom-list" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from provider" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from provider" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from ownership" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from ownership" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from ip-version" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from ip-version" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from multihop" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from multihop" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from help" -f -a "location" -d 'Location of entry relay. This can be \'any\' or any location that is valid with \'set location\', such as \'se got\''
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from help" -f -a "custom-list" -d 'Name of custom list to use to pick entry endpoint'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and __fish_seen_subcommand_from location" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and __fish_seen_subcommand_from location" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and __fish_seen_subcommand_from custom-list" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and __fish_seen_subcommand_from custom-list" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from help" -f -a "location" -d 'Location of entry relay. This can be \'any\' or any location that is valid with \'set location\', such as \'se got\''
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from help" -f -a "custom-list" -d 'Name of custom list to use to pick entry endpoint'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from custom" -l v4-gateway -d 'IPv4 gateway address' -r
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from custom" -l v6-gateway -d 'IPv6 gateway address' -r
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from custom" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from custom" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "location" -d 'Select a relay using country, city or hostname. The \'mullvad relay list\' command shows the available relays and their geographical location'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "custom-list" -d 'Set custom list to select relays from. Use the \'custom-lists list\' command to show available alternatives'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "provider" -d 'Set hosting provider(s) to select relays from. The \'list\' command shows the available relays and their providers'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "ownership" -d 'Filter relays based on ownership. The \'list\' command shows the available relays and whether they\'re rented'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "ip-version" -d 'Set tunnel IP version constraint'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "multihop" -d 'Enable or disable multihop'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "entry" -d 'Set entry location constraints for multihop'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "custom" -d 'Set a custom WireGuard relay'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list" -f -a "location" -d 'Location of entry relay. This can be \'any\' or any location that is valid with \'set location\', such as \'se got\''
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list" -f -a "custom-list" -d 'Name of custom list to use to pick entry endpoint'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from update" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from update" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Show current custom fields for servers'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Set a custom field for a server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all; and not __fish_seen_subcommand_from help" -f -a "unset" -d 'Unset a custom field for a server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all; and not __fish_seen_subcommand_from help" -f -a "clear-all" -d 'Unset custom IPs for all servers'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "ipv4" -d 'Override entry IPv4 address for a given relay'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "ipv6" -d 'Override entry IPv6 address for a given relay'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from ipv4" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from ipv4" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from ipv6" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from ipv6" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "ipv4" -d 'Override entry IPv4 address for a given relay'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "ipv6" -d 'Override entry IPv6 address for a given relay'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "ipv4" -d 'Remove overridden entry IPv4 address for the given server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "ipv6" -d 'Remove overridden entry IPv6 address for the given server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and __fish_seen_subcommand_from ipv4" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and __fish_seen_subcommand_from ipv4" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and __fish_seen_subcommand_from ipv6" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and __fish_seen_subcommand_from ipv6" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "ipv4" -d 'Remove overridden entry IPv4 address for the given server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "ipv6" -d 'Remove overridden entry IPv6 address for the given server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from clear-all" -s y -l confirm -d 'Clear overrides without asking for confirmation'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from clear-all" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from clear-all" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Show current custom fields for servers'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Set a custom field for a server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all; and not __fish_seen_subcommand_from help" -f -a "unset" -d 'Unset a custom field for a server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all; and not __fish_seen_subcommand_from help" -f -a "clear-all" -d 'Unset custom IPs for all servers'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6" -f -a "ipv4" -d 'Override entry IPv4 address for a given relay'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6" -f -a "ipv6" -d 'Override entry IPv6 address for a given relay'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6" -f -a "ipv4" -d 'Remove overridden entry IPv4 address for the given server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6" -f -a "ipv6" -d 'Remove overridden entry IPv6 address for the given server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display the current relay constraints'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Set relay constraints, such as location and port'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -f -a "list" -d 'List available relays'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -f -a "update" -d 'Update the relay list'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -f -a "override" -d 'Override options for individual relays/servers'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "location" -d 'Select a relay using country, city or hostname. The \'mullvad relay list\' command shows the available relays and their geographical location'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "custom-list" -d 'Set custom list to select relays from. Use the \'custom-lists list\' command to show available alternatives'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "provider" -d 'Set hosting provider(s) to select relays from. The \'list\' command shows the available relays and their providers'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "ownership" -d 'Filter relays based on ownership. The \'list\' command shows the available relays and whether they\'re rented'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "ip-version" -d 'Set tunnel IP version constraint'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "multihop" -d 'Enable or disable multihop'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "entry" -d 'Set entry location constraints for multihop'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "custom" -d 'Set a custom WireGuard relay'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list" -f -a "location" -d 'Location of entry relay. This can be \'any\' or any location that is valid with \'set location\', such as \'se got\''
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list" -f -a "custom-list" -d 'Name of custom list to use to pick entry endpoint'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all" -f -a "get" -d 'Show current custom fields for servers'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all" -f -a "set" -d 'Set a custom field for a server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all" -f -a "unset" -d 'Unset a custom field for a server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all" -f -a "clear-all" -d 'Unset custom IPs for all servers'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6" -f -a "ipv4" -d 'Override entry IPv4 address for a given relay'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6" -f -a "ipv6" -d 'Override entry IPv6 address for a given relay'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6" -f -a "ipv4" -d 'Remove overridden entry IPv4 address for the given server'
complete -c mullvad -n "__fish_seen_subcommand_from relay; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6" -f -a "ipv6" -d 'Remove overridden entry IPv6 address for the given server'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display the current API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "add" -d 'Add a custom API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "list" -d 'Lists all API access methods'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "edit" -d 'Edit a custom API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove a custom API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "enable" -d 'Enable an API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "disable" -d 'Disable an API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "use" -d 'Try to use a specific API access method (If the API is unreachable, reverts back to the previous access method)'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "test" -d 'Try to reach the Mullvad API using a specific access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from help" -f -a "socks5" -d 'Configure a SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from help" -f -a "shadowsocks" -d 'Configure a custom Shadowsocks proxy to use as an API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local; and not __fish_seen_subcommand_from help" -f -a "remote" -d 'Configure a remote SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local; and not __fish_seen_subcommand_from help" -f -a "local" -d 'Configure a local SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and __fish_seen_subcommand_from remote" -s u -l username -d 'Username for authentication against a remote SOCKS5 proxy' -r
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and __fish_seen_subcommand_from remote" -s p -l password -d 'Password for authentication against a remote SOCKS5 proxy' -r
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and __fish_seen_subcommand_from remote" -s d -l disabled -d 'Disable the use of this custom access method. It has to be manually enabled at a later stage to be used when accessing the Mullvad API'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and __fish_seen_subcommand_from remote" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and __fish_seen_subcommand_from remote" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and __fish_seen_subcommand_from local" -l transport-protocol -d 'The Mullvad App can not know which transport protocol that the remote peer accepts, but it needs to know this in order to correctly exempt the connection traffic in the firewall' -r
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and __fish_seen_subcommand_from local" -s d -l disabled -d 'Disable the use of this custom access method. It has to be manually enabled at a later stage to be used when accessing the Mullvad API'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and __fish_seen_subcommand_from local" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and __fish_seen_subcommand_from local" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local; and not __fish_seen_subcommand_from help" -f -a "remote" -d 'Configure a remote SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local; and not __fish_seen_subcommand_from help" -f -a "local" -d 'Configure a local SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from shadowsocks" -l cipher -d 'Cipher to use' -r -f -a "{aes-128-cfb	'',aes-128-cfb1	'',aes-128-cfb8	'',aes-128-cfb128	'',aes-256-cfb	'',aes-256-cfb1	'',aes-256-cfb8	'',aes-256-cfb128	'',rc4	'',rc4-md5	'',chacha20	'',salsa20	'',chacha20-ietf	'',aes-128-gcm	'',aes-256-gcm	'',chacha20-ietf-poly1305	'',xchacha20-ietf-poly1305	'',aes-128-pmac-siv	'',aes-256-pmac-siv	''}"
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from shadowsocks" -s d -l disabled -d 'Disable the use of this custom access method. It has to be manually enabled at a later stage to be used when accessing the Mullvad API'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from shadowsocks" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from shadowsocks" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from help" -f -a "socks5" -d 'Configure a SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from help" -f -a "shadowsocks" -d 'Configure a custom Shadowsocks proxy to use as an API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local" -f -a "remote" -d 'Configure a remote SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local" -f -a "local" -d 'Configure a local SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from edit" -l name -d 'Name of the API access method in the Mullvad client \\[All\\]' -r
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from edit" -l username -d 'Username for authentication \\[Socks5 (Remote proxy)\\]' -r
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from edit" -l password -d 'Password for authentication \\[Socks5 (Remote proxy), Shadowsocks\\]' -r
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from edit" -l cipher -d 'Cipher to use \\[Shadowsocks\\]' -r -f -a "{aes-128-cfb	'',aes-128-cfb1	'',aes-128-cfb8	'',aes-128-cfb128	'',aes-256-cfb	'',aes-256-cfb1	'',aes-256-cfb8	'',aes-256-cfb128	'',rc4	'',rc4-md5	'',chacha20	'',salsa20	'',chacha20-ietf	'',aes-128-gcm	'',aes-256-gcm	'',chacha20-ietf-poly1305	'',xchacha20-ietf-poly1305	'',aes-128-pmac-siv	'',aes-256-pmac-siv	''}"
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from edit" -l ip -d 'The IP of the remote proxy server \\[Socks5 (Local & Remote proxy), Shadowsocks\\]' -r
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from edit" -l port -d 'The port of the remote proxy server \\[Socks5 (Local & Remote proxy), Shadowsocks\\]' -r
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from edit" -l local-port -d 'The port that the server on localhost is listening on \\[Socks5 (Local proxy)\\]' -r
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from edit" -l transport-protocol -d 'The transport protocol used by the remote proxy \\[Socks5 (Local proxy)\\]' -r
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from edit" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from edit" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from remove" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from remove" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from enable" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from enable" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from disable" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from disable" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from use" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from use" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from test" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from test" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Display the current API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "add" -d 'Add a custom API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "list" -d 'Lists all API access methods'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "edit" -d 'Edit a custom API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove a custom API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "enable" -d 'Enable an API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "disable" -d 'Disable an API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "use" -d 'Try to use a specific API access method (If the API is unreachable, reverts back to the previous access method)'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "test" -d 'Try to reach the Mullvad API using a specific access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from shadowsocks" -f -a "socks5" -d 'Configure a SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from shadowsocks" -f -a "shadowsocks" -d 'Configure a custom Shadowsocks proxy to use as an API access method'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local" -f -a "remote" -d 'Configure a remote SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local" -f -a "local" -d 'Configure a local SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Get current anti-censorship settings'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Set anti-censorship settings'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port; and not __fish_seen_subcommand_from help" -f -a "mode" -d 'Specify which anti-censorship method to use, if any'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port; and not __fish_seen_subcommand_from help" -f -a "udp2tcp" -d 'Configure udp2tcp anti-censorship'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port; and not __fish_seen_subcommand_from help" -f -a "shadowsocks" -d 'Configure Shadowsocks anti-censorship'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port; and not __fish_seen_subcommand_from help" -f -a "wireguard-port" -d 'Configure WireGuard port anti-censorship'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from mode" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from mode" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from udp2tcp" -s p -l port -d 'Port to use, or \'any\'' -r
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from udp2tcp" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from udp2tcp" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from shadowsocks" -s p -l port -d 'Port to use, or \'any\'' -r
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from shadowsocks" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from shadowsocks" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from wireguard-port" -s p -l port -d 'Port to use' -r
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from wireguard-port" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from wireguard-port" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port; and not __fish_seen_subcommand_from help" -f -a "mode" -d 'Specify which anti-censorship method to use, if any'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port; and not __fish_seen_subcommand_from help" -f -a "udp2tcp" -d 'Configure udp2tcp anti-censorship'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port; and not __fish_seen_subcommand_from help" -f -a "shadowsocks" -d 'Configure Shadowsocks anti-censorship'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port; and not __fish_seen_subcommand_from help" -f -a "wireguard-port" -d 'Configure WireGuard port anti-censorship'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Get current anti-censorship settings'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Set anti-censorship settings'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port" -f -a "mode" -d 'Specify which anti-censorship method to use, if any'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port" -f -a "udp2tcp" -d 'Configure udp2tcp anti-censorship'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port" -f -a "shadowsocks" -d 'Configure Shadowsocks anti-censorship'
complete -c mullvad -n "__fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port" -f -a "wireguard-port" -d 'Configure WireGuard port anti-censorship'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from help" -f -a "list" -d 'List all processes that are excluded from the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from help" -f -a "add" -d 'Add a PID to exclude from the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from help" -f -a "delete" -d 'Stop excluding a PID from the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from help" -f -a "clear" -d 'Stop excluding all processes from the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from add" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from add" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from delete" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from clear" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from clear" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from help" -f -a "list" -d 'List all processes that are excluded from the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from help" -f -a "add" -d 'Add a PID to exclude from the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from help" -f -a "delete" -d 'Stop excluding a PID from the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from help" -f -a "clear" -d 'Stop excluding all processes from the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from split-tunnel; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from status; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -s v -l verbose -d 'Enable verbose output'
complete -c mullvad -n "__fish_seen_subcommand_from status; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -s d -l debug -d 'Enable debug output'
complete -c mullvad -n "__fish_seen_subcommand_from status; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -s j -l json -d 'Format output as JSON'
complete -c mullvad -n "__fish_seen_subcommand_from status; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from status; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from status; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -f -a "listen" -d 'Listen for tunnel state changes'
complete -c mullvad -n "__fish_seen_subcommand_from status; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from status; and __fish_seen_subcommand_from listen" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from status; and __fish_seen_subcommand_from listen" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from status; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -f -a "listen" -d 'Listen for tunnel state changes'
complete -c mullvad -n "__fish_seen_subcommand_from status; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Show current tunnel options'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Set tunnel options'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "mtu" -d 'Configure the tunnel MTU, or \'any\''
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "quantum-resistant" -d 'Configure quantum-resistant key exchange'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "daita" -d 'Configure whether to enable DAITA'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "daita-direct-only" -d 'Configure whether to enable DAITA direct only'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "allowed-ips" -d 'Specify custom allowed IPs for WireGuard tunnels. Use comma-separated values of IPs and IP ranges in CIDR notation. A empty string resets to the default value, where all traffic is allowed, i.e. (0.0.0.0/0,::/0). For CIDR ranges, host bits must be zero (e.g., "10.0.0.0/24" is valid, "10.0.0.1/24" is not)'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "rotation-interval" -d 'The key rotation interval. Number of hours, or \'any\''
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "rotate-key" -d 'Replace the WireGuard key with a new one'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "ipv6" -d 'Enable or disable IPv6 in the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from mtu" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from mtu" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from quantum-resistant" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from quantum-resistant" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from daita" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from daita" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from daita-direct-only" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from daita-direct-only" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from allowed-ips" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from allowed-ips" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from rotation-interval" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from rotation-interval" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from rotate-key" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from rotate-key" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from ipv6" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from ipv6" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "mtu" -d 'Configure the tunnel MTU, or \'any\''
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "quantum-resistant" -d 'Configure quantum-resistant key exchange'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "daita" -d 'Configure whether to enable DAITA'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "daita-direct-only" -d 'Configure whether to enable DAITA direct only'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "allowed-ips" -d 'Specify custom allowed IPs for WireGuard tunnels. Use comma-separated values of IPs and IP ranges in CIDR notation. A empty string resets to the default value, where all traffic is allowed, i.e. (0.0.0.0/0,::/0). For CIDR ranges, host bits must be zero (e.g., "10.0.0.0/24" is valid, "10.0.0.1/24" is not)'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "rotation-interval" -d 'The key rotation interval. Number of hours, or \'any\''
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "rotate-key" -d 'Replace the WireGuard key with a new one'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "ipv6" -d 'Enable or disable IPv6 in the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "get" -d 'Show current tunnel options'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Set tunnel options'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "mtu" -d 'Configure the tunnel MTU, or \'any\''
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "quantum-resistant" -d 'Configure quantum-resistant key exchange'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "daita" -d 'Configure whether to enable DAITA'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "daita-direct-only" -d 'Configure whether to enable DAITA direct only'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "allowed-ips" -d 'Specify custom allowed IPs for WireGuard tunnels. Use comma-separated values of IPs and IP ranges in CIDR notation. A empty string resets to the default value, where all traffic is allowed, i.e. (0.0.0.0/0,::/0). For CIDR ranges, host bits must be zero (e.g., "10.0.0.0/24" is valid, "10.0.0.1/24" is not)'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "rotation-interval" -d 'The key rotation interval. Number of hours, or \'any\''
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "rotate-key" -d 'Replace the WireGuard key with a new one'
complete -c mullvad -n "__fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "ipv6" -d 'Enable or disable IPv6 in the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from version" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from version" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from shell-completions" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from shell-completions" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from factory-reset" -s y -l assume-yes
complete -c mullvad -n "__fish_seen_subcommand_from factory-reset" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from factory-reset" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from reset-settings" -s y -l assume-yes
complete -c mullvad -n "__fish_seen_subcommand_from reset-settings" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from reset-settings" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from help" -f -a "new" -d 'Create a new custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from help" -f -a "list" -d 'Show all custom lists or retrieve a specific custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from help" -f -a "edit" -d 'Edit a custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete a custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from new" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from new" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename; and not __fish_seen_subcommand_from help" -f -a "add" -d 'Add a location to some custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename; and not __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove a location from some custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename; and not __fish_seen_subcommand_from help" -f -a "rename" -d 'Rename a custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and __fish_seen_subcommand_from add" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and __fish_seen_subcommand_from add" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and __fish_seen_subcommand_from remove" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and __fish_seen_subcommand_from remove" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and __fish_seen_subcommand_from rename" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and __fish_seen_subcommand_from rename" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename; and not __fish_seen_subcommand_from help" -f -a "add" -d 'Add a location to some custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename; and not __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove a location from some custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename; and not __fish_seen_subcommand_from help" -f -a "rename" -d 'Rename a custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from delete" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from help" -f -a "new" -d 'Create a new custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from help" -f -a "list" -d 'Show all custom lists or retrieve a specific custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from help" -f -a "edit" -d 'Edit a custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete a custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename" -f -a "add" -d 'Add a location to some custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename" -f -a "remove" -d 'Remove a location from some custom list'
complete -c mullvad -n "__fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename" -f -a "rename" -d 'Rename a custom list'
complete -c mullvad -n "__fish_seen_subcommand_from import-settings" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from import-settings" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from export-settings" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from export-settings" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from log; and not __fish_seen_subcommand_from set-level; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from log; and not __fish_seen_subcommand_from set-level; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from log; and not __fish_seen_subcommand_from set-level; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -f -a "set-level" -d 'Set the log level for the daemon'
complete -c mullvad -n "__fish_seen_subcommand_from log; and not __fish_seen_subcommand_from set-level; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -f -a "listen" -d 'Follow live updates to the daemon log file. Analogue to running `tail -f` on the daemon log file'
complete -c mullvad -n "__fish_seen_subcommand_from log; and not __fish_seen_subcommand_from set-level; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from log; and __fish_seen_subcommand_from set-level" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from log; and __fish_seen_subcommand_from set-level" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from log; and __fish_seen_subcommand_from listen" -s h -l help -d 'Print help'
complete -c mullvad -n "__fish_seen_subcommand_from log; and __fish_seen_subcommand_from listen" -s V -l version -d 'Print version'
complete -c mullvad -n "__fish_seen_subcommand_from log; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from set-level; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -f -a "set-level" -d 'Set the log level for the daemon'
complete -c mullvad -n "__fish_seen_subcommand_from log; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from set-level; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -f -a "listen" -d 'Follow live updates to the daemon log file. Analogue to running `tail -f` on the daemon log file'
complete -c mullvad -n "__fish_seen_subcommand_from log; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from set-level; and not __fish_seen_subcommand_from listen; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "account" -d 'Control and display information about your Mullvad account'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "auto-connect" -d 'Control the daemon auto-connect setting'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "beta-program" -d 'Receive notifications about beta updates'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "lockdown-mode" -d 'Control whether to block network access when disconnected from VPN'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "debug" -d 'Debug commands used for internal testing of the app'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "dns" -d 'Configure DNS servers to use when connected'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "lan" -d 'Control the allow local network sharing setting'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "connect" -d 'Connect to a VPN relay'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "disconnect" -d 'Disconnect from the VPN'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "reconnect" -d 'Reconnect to any matching VPN relay'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "relay" -d 'Manage relay and tunnel constraints'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "api-access" -d 'Manage Mullvad API access methods'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "anti-censorship" -d 'Manage use of anti censorship methods for WireGuard. Can make WireGuard traffic look like something else on the network. Helps circumvent censorship and to establish a tunnel when on restricted networks'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "split-tunnel" -d 'Manage split tunneling. To launch applications outside the tunnel, use the program \'mullvad-exclude\' instead of this command'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "status" -d 'Return the state of the VPN tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "tunnel" -d 'Manage tunnel options'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "version" -d 'Show information about the current Mullvad version and available versions'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "shell-completions" -d 'Generate completion scripts for the specified shell'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "factory-reset" -d 'Reset settings, caches, and logs'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "reset-settings" -d 'Reset settings only, but remain logged in and keep logs and caches'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "custom-list" -d 'Manage custom lists'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "import-settings" -d 'Apply a JSON patch generated by \'export-settings\''
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "export-settings" -d 'Export a JSON patch based on the current settings'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "log" -d 'Manage logs and tracing'
complete -c mullvad -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from connect; and not __fish_seen_subcommand_from disconnect; and not __fish_seen_subcommand_from reconnect; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from shell-completions; and not __fish_seen_subcommand_from factory-reset; and not __fish_seen_subcommand_from reset-settings; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from import-settings; and not __fish_seen_subcommand_from export-settings; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem" -f -a "create" -d 'Create and log in on a new account'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem" -f -a "login" -d 'Log in on an account'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem" -f -a "logout" -d 'Log out of the current account'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem" -f -a "get" -d 'Display information about the current account'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem" -f -a "list-devices" -d 'List devices associated with an account'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem" -f -a "revoke-device" -d 'Revoke a device associated with an account'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list-devices; and not __fish_seen_subcommand_from revoke-device; and not __fish_seen_subcommand_from redeem" -f -a "redeem" -d 'Redeem a voucher'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "get" -d 'Display the current auto-connect setting'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from auto-connect; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "set" -d 'Change auto-connect setting'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "get" -d 'Get beta notifications setting'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from beta-program; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "set" -d 'Change beta notifications setting'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "get" -d 'Display the current lockdown mode setting'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from lockdown-mode; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "set" -d 'Change the lockdown mode setting'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout" -f -a "block-connection" -d 'Block all internet connection by setting an invalid relay constraint'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout" -f -a "relay" -d 'Relay'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from debug; and not __fish_seen_subcommand_from block-connection; and not __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from rollout" -f -a "rollout" -d 'Handy commands for interacting with the app release rollout system'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from enable" -f -a "disable" -d 'Inactivate this _category of relays_ - a category can be one of the following: a relay, a city, a country'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from debug; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from enable" -f -a "enable" -d '(Re)Activate this _category of relays_ - a category can be one of the following: a relay, a city, a country'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed" -f -a "get" -d 'Print your rollout threshold'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed" -f -a "reroll" -d 'Generate a new rollout threshold (overwrites the current threshold value)'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from debug; and __fish_seen_subcommand_from rollout; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from reroll; and not __fish_seen_subcommand_from seed" -f -a "seed" -d 'Set your rollout threshold seed to a known value'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "get" -d 'Display the current DNS settings'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from dns; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "set" -d 'Set DNS servers to use'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from default; and not __fish_seen_subcommand_from custom" -f -a "default" -d 'Use a default DNS server, with or without content blocking'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from dns; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from default; and not __fish_seen_subcommand_from custom" -f -a "custom" -d 'Set a list of custom DNS servers'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "get" -d 'Display the current local network sharing setting'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from lan; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "set" -d 'Change allow LAN setting'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override" -f -a "get" -d 'Display the current relay constraints'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override" -f -a "set" -d 'Set relay constraints, such as location and port'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override" -f -a "list" -d 'List available relays'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override" -f -a "update" -d 'Update the relay list'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from override" -f -a "override" -d 'Override options for individual relays/servers'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "location" -d 'Select a relay using country, city or hostname. The \'mullvad relay list\' command shows the available relays and their geographical location'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "custom-list" -d 'Set custom list to select relays from. Use the \'custom-lists list\' command to show available alternatives'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "provider" -d 'Set hosting provider(s) to select relays from. The \'list\' command shows the available relays and their providers'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "ownership" -d 'Filter relays based on ownership. The \'list\' command shows the available relays and whether they\'re rented'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "ip-version" -d 'Set tunnel IP version constraint'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "multihop" -d 'Enable or disable multihop'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "entry" -d 'Set entry location constraints for multihop'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from provider; and not __fish_seen_subcommand_from ownership; and not __fish_seen_subcommand_from ip-version; and not __fish_seen_subcommand_from multihop; and not __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from custom" -f -a "custom" -d 'Set a custom WireGuard relay'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list" -f -a "location" -d 'Location of entry relay. This can be \'any\' or any location that is valid with \'set location\', such as \'se got\''
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from set; and __fish_seen_subcommand_from entry; and not __fish_seen_subcommand_from location; and not __fish_seen_subcommand_from custom-list" -f -a "custom-list" -d 'Name of custom list to use to pick entry endpoint'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all" -f -a "get" -d 'Show current custom fields for servers'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all" -f -a "set" -d 'Set a custom field for a server'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all" -f -a "unset" -d 'Unset a custom field for a server'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from clear-all" -f -a "clear-all" -d 'Unset custom IPs for all servers'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6" -f -a "ipv4" -d 'Override entry IPv4 address for a given relay'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6" -f -a "ipv6" -d 'Override entry IPv6 address for a given relay'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6" -f -a "ipv4" -d 'Remove overridden entry IPv4 address for the given server'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from relay; and __fish_seen_subcommand_from override; and __fish_seen_subcommand_from unset; and not __fish_seen_subcommand_from ipv4; and not __fish_seen_subcommand_from ipv6" -f -a "ipv6" -d 'Remove overridden entry IPv6 address for the given server'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test" -f -a "get" -d 'Display the current API access method'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test" -f -a "add" -d 'Add a custom API access method'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test" -f -a "list" -d 'Lists all API access methods'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test" -f -a "edit" -d 'Edit a custom API access method'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test" -f -a "remove" -d 'Remove a custom API access method'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test" -f -a "enable" -d 'Enable an API access method'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test" -f -a "disable" -d 'Disable an API access method'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test" -f -a "use" -d 'Try to use a specific API access method (If the API is unreachable, reverts back to the previous access method)'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from enable; and not __fish_seen_subcommand_from disable; and not __fish_seen_subcommand_from use; and not __fish_seen_subcommand_from test" -f -a "test" -d 'Try to reach the Mullvad API using a specific access method'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from shadowsocks" -f -a "socks5" -d 'Configure a SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from shadowsocks" -f -a "shadowsocks" -d 'Configure a custom Shadowsocks proxy to use as an API access method'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local" -f -a "remote" -d 'Configure a remote SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from api-access; and __fish_seen_subcommand_from add; and __fish_seen_subcommand_from socks5; and not __fish_seen_subcommand_from remote; and not __fish_seen_subcommand_from local" -f -a "local" -d 'Configure a local SOCKS5 proxy'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "get" -d 'Get current anti-censorship settings'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from anti-censorship; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "set" -d 'Set anti-censorship settings'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port" -f -a "mode" -d 'Specify which anti-censorship method to use, if any'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port" -f -a "udp2tcp" -d 'Configure udp2tcp anti-censorship'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port" -f -a "shadowsocks" -d 'Configure Shadowsocks anti-censorship'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from anti-censorship; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mode; and not __fish_seen_subcommand_from udp2tcp; and not __fish_seen_subcommand_from shadowsocks; and not __fish_seen_subcommand_from wireguard-port" -f -a "wireguard-port" -d 'Configure WireGuard port anti-censorship'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear" -f -a "list" -d 'List all processes that are excluded from the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear" -f -a "add" -d 'Add a PID to exclude from the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear" -f -a "delete" -d 'Stop excluding a PID from the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from split-tunnel; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from clear" -f -a "clear" -d 'Stop excluding all processes from the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from listen" -f -a "listen" -d 'Listen for tunnel state changes'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "get" -d 'Show current tunnel options'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from tunnel; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from set" -f -a "set" -d 'Set tunnel options'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "mtu" -d 'Configure the tunnel MTU, or \'any\''
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "quantum-resistant" -d 'Configure quantum-resistant key exchange'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "daita" -d 'Configure whether to enable DAITA'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "daita-direct-only" -d 'Configure whether to enable DAITA direct only'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "allowed-ips" -d 'Specify custom allowed IPs for WireGuard tunnels. Use comma-separated values of IPs and IP ranges in CIDR notation. A empty string resets to the default value, where all traffic is allowed, i.e. (0.0.0.0/0,::/0). For CIDR ranges, host bits must be zero (e.g., "10.0.0.0/24" is valid, "10.0.0.1/24" is not)'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "rotation-interval" -d 'The key rotation interval. Number of hours, or \'any\''
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "rotate-key" -d 'Replace the WireGuard key with a new one'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from tunnel; and __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from mtu; and not __fish_seen_subcommand_from quantum-resistant; and not __fish_seen_subcommand_from daita; and not __fish_seen_subcommand_from daita-direct-only; and not __fish_seen_subcommand_from allowed-ips; and not __fish_seen_subcommand_from rotation-interval; and not __fish_seen_subcommand_from rotate-key; and not __fish_seen_subcommand_from ipv6" -f -a "ipv6" -d 'Enable or disable IPv6 in the tunnel'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete" -f -a "new" -d 'Create a new custom list'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete" -f -a "list" -d 'Show all custom lists or retrieve a specific custom list'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete" -f -a "edit" -d 'Edit a custom list'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from custom-list; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from delete" -f -a "delete" -d 'Delete a custom list'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename" -f -a "add" -d 'Add a location to some custom list'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename" -f -a "remove" -d 'Remove a location from some custom list'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from custom-list; and __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from rename" -f -a "rename" -d 'Rename a custom list'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from set-level; and not __fish_seen_subcommand_from listen" -f -a "set-level" -d 'Set the log level for the daemon'
complete -c mullvad -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from set-level; and not __fish_seen_subcommand_from listen" -f -a "listen" -d 'Follow live updates to the daemon log file. Analogue to running `tail -f` on the daemon log file'
